Residual

Trait Residual 

pub trait Residual<O> {
    type TryType: Try<Output = O, Residual = Self>;
}
Allows retrieving the canonical type implementing Try that has this type as its residual and allows it to hold an O as its output.

see ::core::ops::Residual

Required Associated Types

type TryType: Try<Output = O, Residual = Self>

The “return” type of this meta-function.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<B, C> Residual<C> for ControlFlow<B, Infallible>

Source

impl<T, E> Residual<T> for Result<Infallible, E>

Source

type TryType = Result<T, E>

Source

impl<T> Residual<T> for Option<Infallible>

Implementors