pub trait Residual<O> {
type TryType: Try<Output = O, Residual = Self>;
}Expand description
Allows retrieving the canonical type implementing Try that has this type
as its residual and allows it to hold an O as its output.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".